<!--
 * @Author: BDFD
 * @Date: 2021-10-27 18:39:19
 * @LastEditTime: 2021-10-27 21:22:31
 * @LastEditors: Please set LastEditors
 * @Description: In User Settings Edit
 * @FilePath: \6.0-PyPI_Missing_Value_Table\README.md
-->

# Package Name

Package function description

## Installation

`pip install execdata`

## How to use it?

import execdata as data
data.encode(df),
data.split(df),
data.model_evaluate(X_train, X_test, y_train, y_test)

## License

copyright @ 2021 BDFD

This repository is licensed under the MIT license. See LICENSE for details.

### References

https://github.com/bdfd/3.1-PyPI_Template
